Learn R Programming

survivalREC (version 1.1)

Beran: Estimation of the conditional distribution function of the response, given the covariate under random censoring.

Description

Computes the conditional survival probability P(T > y|Z = z)

Usage

Beran(time, status, covariate, delta, x, y, kernel = "gaussian", bw, 
lower.tail = FALSE)

Value

Vector with the estimation of the conditional distribution function of the response, given the covariate under random censoring.

Arguments

time

The survival time of the process.

status

Censoring indicator of the total time of the process; 0 if the total time is censored and 1 otherwise.

covariate

Covariate values for obtaining estimates for the conditional probabilities.

delta

Censoring indicator of the covariate.

x

The first time (or covariate value) for obtaining estimates for the conditional probabilities. If missing, 0 will be used.

y

The total time for obtaining estimates for the conditional probabilities.

kernel

A character string specifying the desired kernel. See details below for possible options. Defaults to "gaussian" where the gaussian density kernel will be used.

bw

A single numeric value to compute a kernel density bandwidth.

lower.tail

logical; if FALSE (default), probabilities are P(T > y|Z = z) otherwise, P(T <= y|Z = z).

Author

Gustavo Soutinho and Luis Meira-Machado

Details

Possible options for argument window are "gaussian", "epanechnikov", "tricube", "boxcar", "triangular", "quartic" or "cosine"

References

R. Beran. Nonparametric regression with randomly censored survival data. Technical report, University of California, Berkeley, 1981.

Examples

Run this code
data("bladder4state")
b3state<-multidf(gap1=bladder4state$y1, event1=bladder4state$d1, 
                 gap2=bladder4state$y2, status=bladder4state$d2, 
                 size=bladder4state$size)

head(b3state[[1]])

##P(T>y|size=3)
library(KernSmooth)

obj0 <- b3state[[1]]

h <- dpik(obj0$size)
Beran(time = obj0$time, status = obj0$status, covariate =obj0$size, x = 3, 
y = 50, bw = h)

##P(T<=y|size=3)
Beran(time = obj0$time, status = obj0$status, covariate =obj0$size, x = 3,
 y = 50, bw = h,
lower.tail = TRUE)

Run the code above in your browser using DataLab