Learn R Programming

survivalREC (version 1.1)

WCH3df: Weighted cumulative hazard estimator for three gap times distribution function.

Description

Provides estimates for three gap times distribution function based on Weighted cumulative hazard estimator (WCH).

Usage

WCH3df(object, x, y, z)

Value

Vector with the Weighted cumulative hazard estimates for three gap times distribution function.

Arguments

object

An object of class multidf.

x

The first time for obtaining estimates for the three gap times distribution function.

y

The second time for obtaining estimates for the three gap times distribution function.

z

The third time for obtaining estimates for the three gap times distribution function.

Author

Gustavo Soutinho and Luis Meira-Machado

References

Wang, M.C. and Wells, M.T. (1998). Nonparametric Estimation of successive duration times under dependent censoring, Biometrika 85, 561-572.

See Also

KMW3df, LIN3df and LDM3df.

Examples

Run this code
data("bladder5state")

b4state<-multidf(gap1=bladder5state$y1, event1=bladder4state$d1, 
                 gap2=bladder5state$y2, event2=bladder4state$d2,
                 gap3=bladder5state$y3, status=bladder4state$d3)
                 
head(b4state)[[1]]

WCH3df(b4state, x=13, y=20, z=40)

b4<-multidf(gap1=bladder4$t1, event1=bladder4$d1, 
            gap2=bladder4$t2-bladder4$t1, event2=bladder4$d2,
            gap3=bladder4$t3-bladder4$t2, status=bladder4state$d3)
              
WCH3df(b4, x=13, y=20, z=40)

Run the code above in your browser using DataLab